@@ -360,6 +360,14 @@ int bowl_check_piece_position(Bowl *bowl, int x, int y, int r)
 	return POSVALID;
 }
 
+/** Check if current piece can drop one tile down. */
+int bowl_piece_can_drop(Bowl *bowl)
+{
+	return (bowl_check_piece_position(bowl,
+			bowl->block.x, bowl->block.y+1,
+			bowl->block.rot_id) == POSVALID);
+}
+
 /*
 ====================================================================
 Draw block to offscreen.
@@ -1039,8 +1047,8 @@ Bowl *bowl_create( int x, int y, int preview_x, int preview_y, SDL_Surface *bloc
 		    bowl->firstlevelup_lines = b;
 	    bowl->level = config.starting_level;
     }
-    printf("First level %d requires %d lines.\n",
-		    	    bowl->level,bowl->firstlevelup_lines);
+    //printf("First level %d requires %d lines.\n",
+    //		    	    bowl->level,bowl->firstlevelup_lines);
 
     bowl->stored_key = -1;
     bowl_reset_contents( bowl );
@@ -1064,10 +1072,22 @@ Bowl *bowl_create( int x, int y, int preview_x, int preview_y, SDL_Surface *bloc
     bowl->wav_excellent = sound_chunk_load( "excellent.wav" );
 #endif
 
-    /* das charge */
-    bowl->das_maxcharge = 267;
+    /* das charge, either class 16/6 or fast 10/3 */
+    if (config.hyper_das) {
+	    bowl->das_maxcharge = 167;
+	    bowl->das_drop = 50;
+    } else {
+	    bowl->das_maxcharge = 267;
+	    bowl->das_drop = 100;
+    }
     bowl->das_charge = 0;
-    bowl->das_drop = 100;
+
+    /* lock delay */
+    if (config.modern)
+	    bowl->ldelay_max = 500;
+    else
+	    bowl->ldelay_max = 0;
+    bowl->ldelay_cur = 0;
 
     /* stats are only display for demo, normal and figures */
     if (config.gametype <= 2 || config.gametype <= GAME_TRAINING) {
@@ -1179,7 +1199,7 @@ void bowl_show( Bowl *bowl )
     char aux[24];
 
     /* draw contents? */
-    if ( bowl->draw_contents ) {
+    if ( bowl->draw_contents && !bowl->paused ) {
         bowl->draw_contents = 0;
         bowl_draw_contents( bowl );
     }
@@ -1209,10 +1229,11 @@ void bowl_show( Bowl *bowl )
                     }
                     /* block */
                     if (bowl->are == 0) {
+                	    int id = block_masks[bowl->block.id].blockid;
+                	    if (bowl->ldelay_cur > 0)
+                		    id = 10;
 			    DEST( sdl.screen, x, y, bowl->block_size, bowl->block_size );
-			    SOURCE( bowl->blocks,
-					    block_masks[bowl->block.id].blockid
-					    * bowl->block_size, 0 );
+			    SOURCE( bowl->blocks,id * bowl->block_size, 0 );
 			    blit_surf();
 			    add_refresh_rect( x, y, bowl->block_size, bowl->block_size );
                     }
@@ -1264,11 +1285,31 @@ int bowl_convert_cury2y(Bowl *bowl)
 	return y;
 }
 
+/** Check if a running lock delay is obsolete or lock delay
+ * needs to be started for current block position.
+ */
+void bowl_check_lockdelay(Bowl *bowl)
+{
+	if (bowl->ldelay_max == 0)
+		return;
+	if (bowl->ldelay_cur > 0) {
+		if (bowl_piece_can_drop(bowl)) {
+			bowl->ldelay_cur = 0;
+			bowl->block.cur_y = bowl->block.y * bowl->block_size;
+		}
+	} else {
+		if (!bowl_piece_can_drop(bowl)) {
+			bowl->ldelay_cur = bowl->ldelay_max;
+			bowl->block.cur_y = bowl->block.y * bowl->block_size;
+		}
+	}
+}
+
 void bowl_update( Bowl *bowl, int ms, int game_over )
 {
     int old_y = bowl_convert_cury2y(bowl);
     int hori_movement = 0;
-    int new_rot, hori_mod, ret;
+    int new_rot, hori_mod, vert_mod, ret;
     float vy;
 
     /* SCORE */
@@ -1332,6 +1373,7 @@ void bowl_update( Bowl *bowl, int ms, int game_over )
        		    else {
        			    bowl->block.x += hori_mod;
        			    hori_movement = 1;
+       			    bowl_check_lockdelay(bowl);
        		    }
                 break;
             case KEY_ROT_LEFT:
@@ -1347,34 +1389,58 @@ void bowl_update( Bowl *bowl, int ms, int game_over )
                     if ( new_rot == 4 )
                         new_rot = 0;
                 }
+                /* the original wall kick rules allow for ridiculous
+                 * moves so we go with a relatable simple version.
+                 * it is tried to move the piece one to the right, one
+                 * to the left and then one up (in this order). if
+                 * any if these single steps fails the rotation fails.
+                 */
                 hori_mod = 0;
-                do {
-                    ret = bowl_check_piece_position(bowl,
-                		    bowl->block.x + hori_mod,
-                                    bowl->block.y, new_rot);
-                    if (ret == POSINVAL_LEFT)
-                        hori_mod++;
-                    else if (ret == POSINVAL_RIGHT)
-                        hori_mod--;
-                    else {
-                        if (ret == POSVALID && (config.modern || hori_mod == 0))
-                            bowl->block.rot_id = new_rot;
-                        break;
-                    }
-                } while (abs(hori_mod) < 3);
-                if (ret == POSVALID && hori_mod && config.modern) {
-                    bowl->block.x += hori_mod;
-                    hori_movement = 1;
+                vert_mod = 0;
+                ret = bowl_check_piece_position(bowl,
+                		bowl->block.x, bowl->block.y, new_rot);
+                if (ret != POSVALID) {
+                	if (bowl_check_piece_position(bowl,
+                			bowl->block.x+1, bowl->block.y,
+                			new_rot) == POSVALID) {
+                		hori_mod = 1;
+                		ret = POSVALID;
+                	} else if (bowl_check_piece_position(bowl,
+                			bowl->block.x-1, bowl->block.y,
+                			new_rot) == POSVALID) {
+                		hori_mod = -1;
+                		ret = POSVALID;
+                	} else if (bowl_check_piece_position(bowl,
+                			bowl->block.x, bowl->block.y-1,
+                			new_rot) == POSVALID) {
+                		hori_mod = 0;
+                		vert_mod = -1;
+                		ret = POSVALID;
+                	}
+                }
+                if (ret == POSVALID && (config.modern ||
+                			(hori_mod == 0 && vert_mod==0))) {
+                	bowl->block.rot_id = new_rot;
+                	bowl->block.x += hori_mod;
+                	bowl->block.y += vert_mod;
+                	if (vert_mod)
+                		bowl->block.cur_y = bowl->block.y*bowl->block_size;
+                        bowl_compute_help_pos(bowl);
+                        bowl_check_lockdelay(bowl);
                 }
-                bowl_compute_help_pos( bowl );
                 break;
             case KEY_DROP:
                 if (config.gametype == GAME_TRAINING)
                     bowl_toggle_gravity(bowl);
-                else
+                else {
                     bowl_drop_block(bowl);
+                    bowl_check_lockdelay(bowl);
+                    if (bowl->ldelay_cur > 0)
+                	    bowl->ldelay_cur = 1;
+                }
                 break;
         }
+
         /* update horizontal bowl position */
         int lshift = 0, rshift = 0;
         /* check if left or right shift requested */
@@ -1405,6 +1471,7 @@ void bowl_update( Bowl *bowl, int ms, int game_over )
                 		bowl->block.x += hori_mod;
                 		hori_movement = 1;
                         	bowl->das_charge -= bowl->das_drop;
+                        	bowl_check_lockdelay(bowl);
                 	}
                 }
         }
@@ -1419,48 +1486,63 @@ void bowl_update( Bowl *bowl, int ms, int game_over )
         /* update horizontal float&screen position */
         bowl->block.sx = bowl->block.x * bowl->block_size + bowl->sx;
 
-        /* update vertical float position */
+        /* update vertical position */
         if ( !bowl->controls && !bowl->cpu_down )
         	if ( delay_timed_out( &bowl->cpu_delay, ms ) )
         		bowl->cpu_down = 1;
         vy = bowl->block_vert_vel;
         if ((bowl->controls && keystate[bowl->controls->down]) ||
-        		bowl_cpu_may_move_down(bowl))
+        				bowl_cpu_may_move_down(bowl))
         	if (bowl->block_drop_vel > vy)
         		if (config.modern || (!lshift && !rshift))
         			vy = bowl->block_drop_vel;
-        if (bowl->zero_gravity)
-        	vy = 0; /* for training */
-        bowl->block.cur_y += vy * ms;
-
-        /* update vertical bowl position */
-        bowl->block.y = bowl_convert_cury2y(bowl);
-
-        /* if we entered a new tile check if block stops */
-        if (old_y != bowl->block.y) {
-            if (bowl_check_piece_position(bowl,
-        		    bowl->block.x, bowl->block.y,
-			    bowl->block.rot_id) != POSVALID) {
-        	    /* we collide at current position, insert one above */
-        	    bowl->block.y -= 1;
-        	    bowl->block.cur_y = bowl->block.y * bowl->block_size;
-        	    bowl_insert_block(bowl);
-            }
+        if (!bowl->zero_gravity && bowl->ldelay_cur == 0) {
+        	bowl->block.cur_y += vy * ms;
+        	bowl->block.y = bowl_convert_cury2y(bowl);
         }
 
-        /* update vertical screen position */
-        if ( config.block_by_block )
+        /* skip lock delay with soft drop */
+        if (bowl->controls && keystate[bowl->controls->down])
+        	if (bowl->ldelay_cur > 0)
+        		bowl->ldelay_cur = 1;
+
+        /* check lock delay */
+        if (bowl->ldelay_cur > 0) {
+        	bowl->ldelay_cur -= ms;
+        	if (bowl->ldelay_cur <= 0) {
+        		bowl->ldelay_cur = 0;
+			bowl_insert_block(bowl);
+        	}
+        } else {
+        	/* insert block or start lock delay on y-position change */
+        	if (bowl->block.y - old_y > 1)
+        		fprintf(stderr, "Oops, non-consecutive y-values...\n");
+        	if (bowl->ldelay_max == 0) {
+        	        /* without lock delay, check if new tile was entered and
+        	         * insert block one above on collision
+        	         * FIXME: this requires enough frames to not skip lines
+        	         * otherwise we might tunnel through blocked lines */
+        		if (bowl_check_piece_position(bowl,
+        				bowl->block.x, bowl->block.y,
+        				bowl->block.rot_id) != POSVALID) {
+        			bowl->block.y -= 1;
+        			bowl->block.cur_y = bowl->block.y * bowl->block_size;
+        			bowl_insert_block(bowl);
+        		}
+        	} else {
+        		/* with lock delay check if we can drop further.
+        		 * if not start lock delay */
+        	        bowl_check_lockdelay(bowl);
+        	}
+        }
+
+        /* use discrete y position if configured block_by_block, during
+         * lock delay or if next position is blocked, otherwise go smooth  */
+        if (bowl->ldelay_cur > 0 || config.block_by_block ||
+        				!bowl_piece_can_drop(bowl))
             bowl->block.sy = bowl->block.y * bowl->block_size + bowl->sy;
-        else {
-            /* to allow horizontal movement after the block touched
-               the ground we allow moving into the next block.
-               this shouldn't be seen, of course */
-            if (bowl_check_piece_position(bowl, bowl->block.x,
-        		    bowl->block.y+1, bowl->block.rot_id) == POSVALID)
-                bowl->block.sy = (int)bowl->block.cur_y + bowl->sy;
-            else
-                bowl->block.sy = bowl->block.y * bowl->block_size + bowl->sy;
-        }
+        else
+            bowl->block.sy = (int)bowl->block.cur_y + bowl->sy;
 
         /* clear stored key */
         bowl->stored_key = -1;
