@@ -62,7 +62,7 @@ void config_check_dir()
 void config_reset()
 {
     /* game options */
-    config.gametype = GAME_DEMO;
+    config.gametype = GAME_CLASSIC;
     config.starting_level = 0;
     config.preview = 1;
     strcpy( config.player1.name, "Michael" );
@@ -82,6 +82,7 @@ void config_reset()
     /* controls */
     config.hori_delay = 3;
     config.vert_delay= 3;
+    config.hyper_das = 0;
     config.pause_key = SDLK_p;
     config.player1.controls.left = SDLK_LEFT;
     config.player1.controls.right = SDLK_RIGHT;
@@ -110,6 +111,7 @@ void config_reset()
     config.fullscreen = 0;
     config.fade = 1;
     config.fps = 0; /* frames per second: 0 - 60Hz, 1 - 50Hz */
+    config.show_fps = 0;
     config.bkgnd = 0;
     config.block_by_block = 0;
     /* lbreakout2 event data */
@@ -182,6 +184,7 @@ void config_load( )
     parser_get_int( pd, "fullscreen", &config.fullscreen );
     parser_get_int( pd, "fading", &config.fade );
     parser_get_int( pd, "fps", &config.fps );
+    parser_get_int( pd, "show_fps", &config.show_fps );
     parser_get_int( pd, "background", &config.bkgnd );
     parser_get_int( pd, "static_background", &config.keep_bkgnd );
     parser_get_int( pd, "hori_delay", &config.hori_delay );
@@ -193,6 +196,7 @@ void config_load( )
     parser_get_int( pd, "grap_input", &config.grab );
     parser_get_int( pd, "invert_mouse", &config.invert );
     parser_get_int( pd, "quick_help", &config.quick_help );
+    parser_get_int( pd, "hyper_das", &config.hyper_das );
     parser_free( &pd );
 }
 
@@ -243,6 +247,7 @@ void config_save( )
         fprintf( file, "fullscreen=%i\n", config.fullscreen );
         fprintf( file, "fading=%i\n", config.fade );
         fprintf( file, "fps=%i\n", config.fps );
+        fprintf( file, "show_fps=%i\n", config.show_fps );
         fprintf( file, "background=%i\n", config.bkgnd );
         fprintf( file, "static_background=%i\n", config.keep_bkgnd );
         fprintf( file, "hori_delay=%i\n", config.hori_delay );
@@ -254,5 +259,6 @@ void config_save( )
         fprintf( file, "grab_input=%i\n", config.grab );
         fprintf( file, "invert_mouse=%i\n", config.invert );
         fprintf( file, "quick_help=%i\n", config.quick_help );
+        fprintf( file, "hyper_das=%i\n", config.hyper_das );
     }
 }
