@@ -122,6 +122,7 @@ Hint strings for the menu.
 			"Classic doesn't give you any of this making the game "\
 			"really hard but also very interesting.")
 #define HINT_SHIFTSOUND _("Enable/Disable piece shift sound.")
+#define HINT_DASMODE _("Normal is the classic 16/6 and Fast is 10/3 which roughly equals what hypertappers can achieve.")
                        
 /*
 ====================================================================
@@ -279,7 +280,14 @@ void manager_create()
     filter_set( filter, SDLK_0, SDLK_9, 1 );
     filter_set( filter, SDLK_KP0, SDLK_KP9, 1 );
     filter_set( filter, SDLK_UP, SDLK_PAGEDOWN, 1 );
+    filter[SDLK_RCTRL] = 1;
+    filter[SDLK_LCTRL] = 1;
+    filter[SDLK_RSHIFT] = 1;
+    filter[SDLK_LSHIFT] = 1;
+    filter[SDLK_RALT] = 1;
+    filter[SDLK_LALT] = 1;
     filter[SDLK_SPACE] = 1;
+
     filter[SDLK_ESCAPE] = 0;
     filter[SDLK_RETURN] = 0;
     filter[SDLK_q] = 0;
@@ -351,9 +359,11 @@ void manager_create()
     item->callback = cb_hints;
     menu_add( gfx, item );
     menu_add( gfx, item_create_separator( "" ) );
+#ifndef WIN32
     item = item_create_switch( _("Display:"), HINT_DISPLAY, &config.fullscreen, _("Window"), _("Fullscreen") );
     item->callback = cb_fullscreen;
     menu_add( gfx, item );
+#endif
     menu_add( gfx, item_create_switch_x( _("Frame Rate:"), HINT_FPS, &config.fps, str_fps, 2 ) );
     menu_add( gfx, item_create_separator( "" ) );
     menu_add( gfx, item_create_link( _("Back"), HINT_, _main ) );
@@ -429,6 +439,8 @@ void manager_create()
     //menu_add( cont, item_create_range( _("Vertical Delay:"),  HINT_VERTDEL,&config.vert_delay, 0, 9, 1 ) );
     menu_add( cont, pause_key );
     menu_add( cont, item_create_separator( "" ) );
+    menu_add( cont, item_create_switch( _("DAS Mode:"), HINT_DASMODE, &config.hyper_das, _("Normal"), _("Fast") ));
+    menu_add( cont, item_create_separator( "" ) );
     menu_add( cont, item_create_link( _("Back"), HINT_, _main ) );
     /* controls player 1 */
     for ( k = 0; k < 6; k++ )
@@ -512,6 +524,7 @@ int manager_run()
         }
 		/* fullscreen if no item selected */
 		if ( event_polled ) {
+#ifndef WIN32
 			if ( cur_menu->cur_item == 0 || ( cur_menu->cur_item->type != ITEM_EDIT && cur_menu->cur_item->type != ITEM_KEY ) )
 				if ( event.type == SDL_KEYUP )
 					if ( event.key.keysym.sym == SDLK_f ) {
@@ -521,6 +534,7 @@ int manager_run()
 					    chart_show( chart_set_query_id( chart_id ), cx, cy, cw, ch );
 						refresh_screen( 0, 0 ,0, 0 );
 					}
+#endif
 			/* check if clicked on highscore */
 			if ( event.type == SDL_MOUSEBUTTONUP ) 
 				if ( motion_x >= cx && motion_y >= cy )
@@ -579,7 +593,9 @@ Update screen without menu itself as this is shown next frame.
 */
 void manager_show()
 {
+#ifndef WIN32
     set_video_mode( config.fullscreen );
+#endif
     FULL_DEST( sdl.screen ); FULL_SOURCE( mbkgnd ); blit_surf();
     chart_show( chart_set_query_id( chart_id ), cx, cy, cw, ch );
     add_refresh_rect( 0, 0, sdl.screen->w, sdl.screen->h );
