@@ -360,15 +360,11 @@ void unlock_surf(SDL_Surface *sur)
 */
 void blit_surf(void)
 {
-#ifdef SDL_1_1_5
     if (sdl.s.s->flags & SDL_SRCALPHA)
         SDL_SetAlpha(sdl.s.s, SDL_SRCALPHA, 255 - sdl.s.s->format->alpha);
-#endif
     SDL_BlitSurface(sdl.s.s, &sdl.s.r, sdl.d.s, &sdl.d.r);
-#ifdef SDL_1_1_5
     if (sdl.s.s->flags & SDL_SRCALPHA)
         SDL_SetAlpha(sdl.s.s, SDL_SRCALPHA, 255 - sdl.s.s->format->alpha);
-#endif
 }
 
 /*
@@ -376,11 +372,7 @@ void blit_surf(void)
 */
 void alpha_blit_surf(int alpha)
 {
- #ifdef SDL_1_1_5
     SDL_SetAlpha(sdl.s.s, SDL_SRCALPHA, 255 - alpha);
-#else
-    SDL_SetAlpha(sdl.s.s, SDL_SRCALPHA, alpha);
-#endif
     SDL_BlitSurface(sdl.s.s, &sdl.s.r, sdl.d.s, &sdl.d.r);
     SDL_SetAlpha(sdl.s.s, 0, 0);
 }
@@ -396,15 +388,11 @@ void fill_surf(int c)
 /* set clipping rect */
 void set_surf_clip( SDL_Surface *surf, int x, int y, int w, int h )
 {
-#ifdef SDL_1_1_5
     SDL_Rect rect = { x, y, w, h };
     if ( w == h || h == 0 )
         SDL_SetClipRect( surf, 0 );
     else
         SDL_SetClipRect( surf, &rect );
-#else
-    SDL_SetClipping( surf, x, y, w, h );
-#endif
 }
 
 /* set pixel */
@@ -867,7 +855,9 @@ static void select_best_video_mode(int *best_w, int *best_h)
 	int i;
 	int dratio;
 
-	dratio = 100*display_w/display_h;
+	/* with 100 odd resolutions like 1366x768 will be selected
+	 * with 1000 (first decimal must match) these are ruled out */
+	dratio = 1000*display_w/display_h;
 	wanted_mode.w = display_w;
 	wanted_mode.h = display_h;
 
@@ -890,7 +880,7 @@ static void select_best_video_mode(int *best_w, int *best_h)
 
 		/* select lowest mode with same ratio as display */
 		for(i=0;modes[i];++i)
-			if (100*modes[i]->w/modes[i]->h == dratio) {
+			if (1000*modes[i]->w/modes[i]->h == dratio) {
 				if (modes[i]->h < wanted_mode.h)
 					wanted_mode = *modes[i];
 			}
