@@ -110,10 +110,12 @@ int confirm( Font *font, char *str, int type )
                     }
 					else
 					if ( event.key.keysym.sym == SDLK_f ) {
+#ifndef WIN32
 						config.fullscreen = !config.fullscreen;
 						set_video_mode( config.fullscreen );
 						draw_confirm_screen( font, buffer, str );
 						refresh_screen( 0, 0, 0, 0 );
+#endif
 					}
                 }
                 else
@@ -134,6 +136,14 @@ int confirm( Font *font, char *str, int type )
                             go_on = 0;
                             ret = 0;
                         }
+#ifdef WIN32
+                        /* y/z not recognized properly in windows */
+                        if (event.key.keysym.sym == SDLK_y ||
+                        		event.key.keysym.sym == SDLK_z) {
+                        	go_on = 0;
+                        	ret = 1;
+                        }
+#endif
                     }
                 break;
         }
@@ -341,6 +351,8 @@ void tetris_clear()
 
 /** Display FPS in console */
 void show_fps(int fps) {
+	if (!config.show_fps)
+		return;
 	SDL_Rect r = {0,0,40,20};
 	char str[32];
 	sprintf(str,"%d",fps);
@@ -421,11 +433,14 @@ void tetris_run()
                                         bowl_finish_game( bowls[i] );
                             break;
                          case SDLK_f:
+#ifndef WIN32
                              /* switch fullscreen */
                             config.fullscreen = !config.fullscreen;
                             set_video_mode( config.fullscreen );
                             FULL_DEST( sdl.screen ); FULL_SOURCE( offscreen ); blit_surf();
                             refresh_screen( 0, 0, 0, 0 );
+#endif
+                            break;
                         case SDLK_TAB:
                             sprintf( sshot_str, "ss%i.bmp", screenshot_id++ );
                             SDL_SaveBMP( sdl.screen, sshot_str );
